@@ -1,5 +1,5 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.004';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.005';
 use strict;
 use warnings;
 use Dancer2::Plugin;
@@ -281,7 +281,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -317,7 +317,7 @@ settings.
 No configuration file is required, however, and conversion using ordinary Perl
 code can be accomplshed from with your Dancer2 app like so:
 
-  use Dancer2::Plugin::MarkdownFileToHTML;
+  use Dancer2::Plugin::MarkdownFilesToHTML;
 
   # convert a single markdown file to HTML
   my ($html, $toc) = mdfile_2html('/path/to/file.md',
